Assorted spelling fixes

Francois Gouget fgouget at free.fr
Tue Jan 6 07:00:36 CST 2004


Now that CVS seems to be more in sync with wine-patches and the flow of
commits has slowed down, here's a new round of spelling fixes.


Changelog;

   Assorted spelling fixes.


Index: dlls/comctl32/tab.c
===================================================================
RCS file: /home/cvs/wine/dlls/comctl32/tab.c,v
retrieving revision 1.90
diff -u -r1.90 tab.c
--- dlls/comctl32/tab.c	2 Dec 2003 03:31:44 -0000	1.90
+++ dlls/comctl32/tab.c	14 Dec 2003 10:41:31 -0000
@@ -1060,7 +1060,7 @@
  * list and ignores scrolling and selection.
  * It also uses the current font to determine the height of the tab row and
  * it checks if all the tabs fit in the client area of the window. If they
- * dont, a scrolling control is added.
+ * don't, a scrolling control is added.
  */
 static void TAB_SetItemBounds (HWND hwnd)
 {
Index: dlls/commdlg/filedlg.c
===================================================================
RCS file: /home/cvs/wine/dlls/commdlg/filedlg.c,v
retrieving revision 1.69
diff -u -r1.69 filedlg.c
--- dlls/commdlg/filedlg.c	2 Jan 2004 01:47:52 -0000	1.69
+++ dlls/commdlg/filedlg.c	4 Jan 2004 21:16:19 -0000
@@ -1711,7 +1711,7 @@

   nOpenAction = ONOPEN_BROWSE;

-  /* dont apply any checks with OFN_NOVALIDATE */
+  /* don't apply any checks with OFN_NOVALIDATE */
   {
     LPWSTR lpszTemp, lpszTemp1;
     LPITEMIDLIST pidl = NULL;
Index: dlls/commdlg/finddlg32.c
===================================================================
RCS file: /home/cvs/wine/dlls/commdlg/finddlg32.c,v
retrieving revision 1.22
diff -u -r1.22 finddlg32.c
--- dlls/commdlg/finddlg32.c	10 Sep 2003 03:56:48 -0000	1.22
+++ dlls/commdlg/finddlg32.c	14 Dec 2003 10:42:16 -0000
@@ -54,7 +54,7 @@
  * The find/replace calls are passed a structure that is _not_ used
  * internally. There is a local copy that holds the running info to
  * be able to combine xxxA and xxxW calls. The passed pointer is
- * returned upon sendmessage. Apps wont break this way when they rely
+ * returned upon sendmessage. Apps won't break this way when they rely
  * on the original pointer. This will work as long as the sizes of
  * FINDREPLACEA == FINDREPLACEW. The local copy will also prevent
  * the app to see the wine-specific extra flags to distinguish between
Index: dlls/d3d8/d3d8_private.h
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/d3d8_private.h,v
retrieving revision 1.47
diff -u -r1.47 d3d8_private.h
--- dlls/d3d8/d3d8_private.h	3 Oct 2003 04:35:07 -0000	1.47
+++ dlls/d3d8/d3d8_private.h	5 Jan 2004 12:58:53 -0000
@@ -1298,7 +1298,7 @@
 #if 0 /* NOTE: Must be 0 in cvs */
   /* To avoid having to get gigabytes of trace, the following can be compiled in, and at the start
      of each frame, a check is made for the existence of C:\D3DTRACE, and if if exists d3d trace
-     is enabled, and if it doesnt exists it is disabled.                                           */
+     is enabled, and if it doesn't exists it is disabled.                                           */
 # define FRAME_DEBUGGING
   /*  Adding in the SINGLE_FRAME_DEBUGGING gives a trace of just what makes up a single frame, before
       the file is deleted                                                                            */
Index: dlls/d3d8/directx.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/directx.c,v
retrieving revision 1.56
diff -u -r1.56 directx.c
--- dlls/d3d8/directx.c	17 Nov 2003 20:04:08 -0000	1.56
+++ dlls/d3d8/directx.c	5 Jan 2004 13:01:27 -0000
@@ -458,7 +458,7 @@
         glGetIntegerv(GL_MAX_TEXTURE_SIZE, &gl_tex_size);
     }

-    /* If we dont know the device settings, go query them now */
+    /* If we don't know the device settings, go query them now */
     if (This->isGLInfoValid == FALSE) IDirect3D8Impl_FillGLCaps(iface, NULL);

     pCaps->DeviceType = (DeviceType == D3DDEVTYPE_HAL) ? D3DDEVTYPE_HAL : D3DDEVTYPE_REF;  /* Not quite true, but use h/w supported by opengl I suppose */
@@ -928,7 +928,7 @@

     /* Initialize openGl - Note the visual is chosen as the window is created and the glcontext cannot
          use different properties after that point in time. FIXME: How to handle when requested format
-         doesnt match actual visual? Cannot choose one here - code removed as it ONLY works if the one
+         doesn't match actual visual? Cannot choose one here - code removed as it ONLY works if the one
          it chooses is identical to the one already being used!                                        */
     /* FIXME: Handle stencil appropriately via EnableAutoDepthStencil / AutoDepthStencilFormat */

Index: dlls/d3d8/drawprim.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/drawprim.c,v
retrieving revision 1.15
diff -u -r1.15 drawprim.c
--- dlls/d3d8/drawprim.c	6 Jan 2004 00:36:45 -0000	1.15
+++ dlls/d3d8/drawprim.c	6 Jan 2004 09:52:36 -0000
@@ -180,7 +180,7 @@

     } else if ((This->tracking_color == IS_TRACKING && isDiffuseSupplied == FALSE) ||
                (This->tracking_color == NEEDS_TRACKING && isDiffuseSupplied == FALSE)) {
-        /* If we are tracking the current color but one isnt supplied, dont! */
+        /* If we are tracking the current color but one isn't supplied, don't! */
         glDisable(GL_COLOR_MATERIAL);
         checkGLcall("glDisable GL_COLOR_MATERIAL");
         This->tracking_color = NEEDS_TRACKING;
@@ -225,7 +225,7 @@
     BOOL isLightingOn = FALSE;
     ICOM_THIS(IDirect3DDevice8Impl,iface);

-    /* If no normals, DISABLE lighting otherwise, dont touch lighing as it is
+    /* If no normals, DISABLE lighting otherwise, don't touch lighing as it is
        set by the appropriate render state. Note Vertex Shader output is already lit */
     if (vtx_lit || useVS) {
         isLightingOn = glIsEnabled(GL_LIGHTING);
@@ -538,7 +538,7 @@
     for (textureNo = 0; textureNo < GL_LIMITS(textures); ++textureNo) {

         if (!GL_SUPPORT(ARB_MULTITEXTURE) && textureNo > 0) {
-            FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+            FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
             continue ;
         }

@@ -681,7 +681,7 @@
     /* Blend Data ----------------------------------------------*/
     if ((sd->u.s.blendWeights.lpData != NULL) ||
         (sd->u.s.blendMatrixIndices.lpData != NULL)) {
-        /* FIXME: Wont get here as will drop to slow method        */
+        /* FIXME: Won't get here as will drop to slow method        */
         FIXME("Blending not supported in fast draw routine\n");

 #if 0 /* Vertex blend support needs to be added */
@@ -737,7 +737,7 @@
     if (sd->u.s.pSize.lpData != NULL) {

         /* no such functionality in the fixed function GL pipeline */
-        /* FIXME: Wont get here as will drop to slow method        */
+        /* FIXME: Won't get here as will drop to slow method        */
         FIXME("Cannot change ptSize here in openGl\n");
     }

@@ -829,7 +829,7 @@
             int coordIdx = This->UpdateStateBlock->texture_state[textureNo][D3DTSS_TEXCOORDINDEX];

             if (!GL_SUPPORT(ARB_MULTITEXTURE) && textureNo > 0) {
-                FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+                FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
                 glDisableClientState(GL_TEXTURE_COORD_ARRAY);
                 glMultiTexCoord4fARB(GL_TEXTURE0_ARB + textureNo, 0, 0, 0, 1);
                 continue;
@@ -1021,7 +1021,7 @@
         for (textureNo = 0; textureNo < GL_LIMITS(textures); ++textureNo) {

             if (!GL_SUPPORT(ARB_MULTITEXTURE) && textureNo > 0) {
-                FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+                FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
                 continue ;
             }

Index: dlls/d3d8/stateblock.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/stateblock.c,v
retrieving revision 1.13
diff -u -r1.13 stateblock.c
--- dlls/d3d8/stateblock.c	4 Nov 2003 04:17:52 -0000	1.13
+++ dlls/d3d8/stateblock.c	5 Jan 2004 13:01:58 -0000
@@ -219,7 +219,7 @@
 #endif
             checkGLcall("glActiveTextureARB");
         } else if (i > 0) {
-            FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+            FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
         }

         /* Generate an opengl texture name */
Index: dlls/d3d8/surface.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/surface.c,v
retrieving revision 1.28
diff -u -r1.28 surface.c
--- dlls/d3d8/surface.c	4 Nov 2003 04:17:52 -0000	1.28
+++ dlls/d3d8/surface.c	5 Jan 2004 13:01:42 -0000
@@ -152,7 +152,7 @@
       TRACE("(%p) : rect@%p flags(%08lx), output lockedRect@%p, memory@%p\n", This, pRect, Flags, pLockedRect, This->allocatedMemory);
     }

-    /* DXTn formats dont have exact pitches as they are to the newt row of blocks,
+    /* DXTn formats don't have exact pitches as they are to the new row of blocks,
          where each block is 4x4 pixels, 8 bytes (dxt1) and 16 bytes (dxt3/5)
           ie pitch = (width/4) * bytes per block                                  */
     if (This->myDesc.Format == D3DFMT_DXT1) /* DXT1 is 8 bytes per block */
@@ -252,7 +252,7 @@
     }

     if (Flags & (D3DLOCK_NO_DIRTY_UPDATE | D3DLOCK_READONLY)) {
-      /* Dont dirtify */
+      /* Don't dirtify */
     } else {
       /**
        * Dirtify on lock
Index: dlls/d3d8/utils.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/utils.c,v
retrieving revision 1.12
diff -u -r1.12 utils.c
--- dlls/d3d8/utils.c	19 Sep 2003 00:20:19 -0000	1.12
+++ dlls/d3d8/utils.c	14 Dec 2003 10:43:07 -0000
@@ -660,8 +660,8 @@
     break;
   case D3DTA_SPECULAR:
     /**
-     * According to the GL_ARB_texture_env_combine specs, SPECULAR is 'Secondary color' and
-     * isnt supported until base GL supports it
+     * According to the GL_ARB_texture_env_combine specs, SPECULAR is
+     * 'Secondary color' and isn't supported until base GL supports it
      * There is no concept of temp registers as far as I can tell
      */

Index: dlls/d3d8/volume.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/volume.c,v
retrieving revision 1.9
diff -u -r1.9 volume.c
--- dlls/d3d8/volume.c	5 Sep 2003 23:08:41 -0000	1.9
+++ dlls/d3d8/volume.c	14 Dec 2003 10:38:16 -0000
@@ -146,7 +146,7 @@
     }

     if (Flags & (D3DLOCK_NO_DIRTY_UPDATE | D3DLOCK_READONLY)) {
-      /* Dont dirtify */
+      /* Don't dirtify */
     } else {
       /**
        * Dirtify on lock
Index: dlls/dinput/joystick/linuxinput.c
===================================================================
RCS file: /home/cvs/wine/dlls/dinput/joystick/linuxinput.c,v
retrieving revision 1.20
diff -u -r1.20 linuxinput.c
--- dlls/dinput/joystick/linuxinput.c	5 Jan 2004 21:11:25 -0000	1.20
+++ dlls/dinput/joystick/linuxinput.c	5 Jan 2004 22:58:56 -0000
@@ -460,7 +460,7 @@
     if (xmin == xmax) return val;
     if ((hmin == hmax) || (hmax==xmid) || (hmin==xmid)) return val;

-    /* dont assume total linearity, but linearity starting from a zeropoint */
+    /* don't assume total linearity, but linearity starting from a zeropoint */
     if (val > xmid) {
 	ret = (val-xmid)*((wmax-wmin)/2)/(hmax-xmid)+0;
     } else {
Index: dlls/dinput/mouse/main.c
===================================================================
RCS file: /home/cvs/wine/dlls/dinput/mouse/main.c,v
retrieving revision 1.26
diff -u -r1.26 main.c
--- dlls/dinput/mouse/main.c	28 Oct 2003 21:08:31 -0000	1.26
+++ dlls/dinput/mouse/main.c	14 Dec 2003 10:40:07 -0000
@@ -434,7 +434,7 @@
     /* Only allow mouse events every 10 ms.
      * This is to allow the cursor to start acceleration before
      * the warps happen. But if it involves a mouse button event we
-     * allow it since we dont want to loose the clicks.
+     * allow it since we don't want to loose the clicks.
      */
     if (((GetCurrentTime() - last_event) < 10)
         && wparam == WM_MOUSEMOVE)
Index: dlls/icmp/ip.h
===================================================================
RCS file: /home/cvs/wine/dlls/icmp/ip.h,v
retrieving revision 1.2
diff -u -r1.2 ip.h
--- dlls/icmp/ip.h	9 Mar 2002 23:33:03 -0000	1.2
+++ dlls/icmp/ip.h	14 Dec 2003 10:41:18 -0000
@@ -60,7 +60,7 @@
 	u_short	ip_id;			/* identification */
 	u_short	ip_off;			/* fragment offset field */
 #define	IP_RF 0x8000			/* reserved fragment flag */
-#define	IP_DF 0x4000			/* dont fragment flag */
+#define	IP_DF 0x4000			/* don't fragment flag */
 #define	IP_MF 0x2000			/* more fragments flag */
 #define	IP_OFFMASK 0x1fff		/* mask for fragmenting bits */
 	u_char	ip_ttl;			/* time to live */
Index: dlls/kernel/tests/locale.c
===================================================================
RCS file: /home/cvs/wine/dlls/kernel/tests/locale.c,v
retrieving revision 1.24
diff -u -r1.24 locale.c
--- dlls/kernel/tests/locale.c	8 Dec 2003 22:20:44 -0000	1.24
+++ dlls/kernel/tests/locale.c	14 Dec 2003 10:39:46 -0000
@@ -259,7 +259,7 @@
   ret = GetTimeFormatA(lcid, 0, &curtime, input, buffer, COUNTOF(buffer));
   EXPECT_VALID; EXPECT_LENA; EXPECT_EQA;

-  STRINGSA("h", "text"); /* Dont write to buffer if len is 0*/
+  STRINGSA("h", "text"); /* Don't write to buffer if len is 0 */
   strcpy(buffer, "text");
   ret = GetTimeFormatA(lcid, 0, &curtime, input, buffer, 0);
   EXPECT_VALID; EXPECT_LEN(2); EXPECT_EQA;
Index: dlls/msvcrt/file.c
===================================================================
RCS file: /home/cvs/wine/dlls/msvcrt/file.c,v
retrieving revision 1.60
diff -u -r1.60 file.c
--- dlls/msvcrt/file.c	31 Oct 2003 04:17:45 -0000	1.60
+++ dlls/msvcrt/file.c	14 Dec 2003 10:43:17 -0000
@@ -138,7 +138,7 @@
   MSVCRT_flags[fd] = 0;
   TRACE(":fd (%d) freed\n",fd);
   if (fd < 3)
-    return; /* dont use 0,1,2 for user files */
+    return; /* don't use 0,1,2 for user files */
   if (fd == MSVCRT_fdend - 1)
     MSVCRT_fdend--;
   if (fd < MSVCRT_fdstart)
@@ -450,7 +450,7 @@
 		MSVCRT_free(MSVCRT_files[fd]->_base);
   }

-  /* Dont free std FILE*'s, they are not dynamic */
+  /* Don't free std FILE*'s, they are not dynamic */
   if (fd > 2 && MSVCRT_files[fd])
     MSVCRT_free(MSVCRT_files[fd]);

@@ -846,7 +846,7 @@
   {
     /* FIXME: I'm not convinced that I should be copying the
      * handle here - it may be leaked if the app doesn't
-     * close it (and the API docs dont say that it should)
+     * close it (and the API docs don't say that it should)
      * Not duplicating it means that it can't be inherited
      * and so lcc's wedit doesn't cope when it passes it to
      * child processes. I've an idea that it should either
@@ -1213,7 +1213,7 @@
   char *bufstart = buf;
   HANDLE hand = msvcrt_fdtoh(fd);

-  /* Dont trace small reads, it gets *very* annoying */
+  /* Don't trace small reads, it gets *very* annoying */
   if (count > 4)
     TRACE(":fd (%d) handle (%p) buf (%p) len (%d)\n",fd,hand,buf,count);
   if (hand == INVALID_HANDLE_VALUE)
@@ -1309,10 +1309,10 @@

   memset(buf,0,sizeof(struct _stati64));

-  /* FIXME: rdev isnt drive num,despite what the docs say-what is it?
+  /* FIXME: rdev isn't drive num, despite what the docs say-what is it?
      Bon 011120: This FIXME seems incorrect
-                 Also a letter as first char isn't enough to be classify
-		 as drive letter
+                 Also a letter as first char isn't enough to be classified
+		 as a drive letter
   */
   if (isalpha(*path)&& (*(path+1)==':'))
     buf->st_dev = buf->st_rdev = toupper(*path) - 'A'; /* drive num */
@@ -1523,7 +1523,7 @@
   DWORD num_written;
   HANDLE hand = msvcrt_fdtoh(fd);

-  /* Dont trace small writes, it gets *very* annoying */
+  /* Don't trace small writes, it gets *very* annoying */
 #if 0
   if (count > 32)
     TRACE(":fd (%d) handle (%d) buf (%p) len (%d)\n",fd,hand,buf,count);
Index: dlls/msvcrt/main.c
===================================================================
RCS file: /home/cvs/wine/dlls/msvcrt/main.c,v
retrieving revision 1.15
diff -u -r1.15 main.c
--- dlls/msvcrt/main.c	17 Mar 2003 21:21:59 -0000	1.15
+++ dlls/msvcrt/main.c	14 Dec 2003 10:39:23 -0000
@@ -153,12 +153,12 @@
    */

   /* Experimentation reveals the following flag meanings when set:
-   * 0x0001 - Dont show __ in calling convention
-   * 0x0002 - Dont show calling convention at all
-   * 0x0004 - Dont show function/method return value
+   * 0x0001 - Don't show __ in calling convention
+   * 0x0002 - Don't show calling convention at all
+   * 0x0004 - Don't show function/method return value
    * 0x0010 - Same as 0x1
-   * 0x0080 - Dont show access specifier (public/protected/private)
-   * 0x0200 - Dont show static specifier
+   * 0x0080 - Don't show access specifier (public/protected/private)
+   * 0x0200 - Don't show static specifier
    * 0x0800 - Unknown, passed by type_info::name()
    * 0x1000 - Only report the variable/class name
    * 0x2000 - Unknown, passed by type_info::name()
Index: dlls/ole32/clipboard.c
===================================================================
RCS file: /home/cvs/wine/dlls/ole32/clipboard.c,v
retrieving revision 1.29
diff -u -r1.29 clipboard.c
--- dlls/ole32/clipboard.c	1 Oct 2003 03:14:29 -0000	1.29
+++ dlls/ole32/clipboard.c	6 Jan 2004 12:21:03 -0000
@@ -287,7 +287,7 @@

 /*
  *  If we need to store state info we can store it here.
- *  For now we dont need this functionality.
+ *  For now we don't need this functionality.
  *
 typedef struct tagClipboardWindowInfo
 {
@@ -733,8 +733,8 @@

     wcex.cbSize         = sizeof(WNDCLASSEXA);
     /* Windows creates this class with a style mask of 0
-     * We dont bother doing this since the FindClassByAtom code
-     * would have to be changed to deal with this idiosyncracy. */
+     * We don't bother doing this since the FindClassByAtom code
+     * would have to be changed to deal with this idiosyncrasy. */
     wcex.style          = CS_GLOBALCLASS;
     wcex.lpfnWndProc    = (WNDPROC)OLEClipbrd_WndProc;
     wcex.hInstance      = 0;
@@ -748,7 +748,7 @@

 /*
  *  If we need to store state info we can store it here.
- *  For now we dont need this functionality.
+ *  For now we don't need this functionality.
  *   ClipboardWindowInfo clipboardInfo;
  *   ZeroMemory( &trackerInfo, sizeof(ClipboardWindowInfo));
  */
Index: dlls/ole32/errorinfo.c
===================================================================
RCS file: /home/cvs/wine/dlls/ole32/errorinfo.c,v
retrieving revision 1.16
diff -u -r1.16 errorinfo.c
--- dlls/ole32/errorinfo.c	11 Sep 2003 03:06:25 -0000	1.16
+++ dlls/ole32/errorinfo.c	14 Dec 2003 10:40:58 -0000
@@ -57,7 +57,7 @@

     /*
      * Allocate a new buffer to hold the string.
-     * dont't forget to keep an empty spot at the beginning of the
+     * don't forget to keep an empty spot at the beginning of the
      * buffer for the character count and an extra character at the
      * end for the '\0'.
      */
Index: dlls/ole32/filemoniker.c
===================================================================
RCS file: /home/cvs/wine/dlls/ole32/filemoniker.c,v
retrieving revision 1.27
diff -u -r1.27 filemoniker.c
--- dlls/ole32/filemoniker.c	1 Oct 2003 03:14:29 -0000	1.27
+++ dlls/ole32/filemoniker.c	14 Dec 2003 10:41:03 -0000
@@ -579,7 +579,7 @@
         res=IBindCtx_GetRunningObjectTable(pbc,&prot);

         if (SUCCEEDED(res)){
-            /* if the requested class was loaded befor ! we dont need to reload it */
+            /* if the requested class was loaded before ! we don't need to reload it */
             res = IRunningObjectTable_GetObject(prot,iface,&pObj);

             if (res==S_FALSE){
Index: dlls/ole32/compositemoniker.c
===================================================================
RCS file: /home/cvs/wine/dlls/ole32/compositemoniker.c,v
retrieving revision 1.25
diff -u -r1.25 compositemoniker.c
--- dlls/ole32/compositemoniker.c	30 Sep 2003 00:24:08 -0000	1.25
+++ dlls/ole32/compositemoniker.c	14 Dec 2003 10:41:07 -0000
@@ -648,7 +648,7 @@

         if (SUCCEEDED(res)){

-            /* if the requested class was loaded befor ! we dont need to reload it */
+            /* if the requested class was loaded before ! we don't need to reload it */
             res = IRunningObjectTable_GetObject(prot,iface,(IUnknown**)ppvResult);

             if (res==S_OK)
Index: dlls/oleaut32/oleaut.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/oleaut.c,v
retrieving revision 1.37
diff -u -r1.37 oleaut.c
--- dlls/oleaut32/oleaut.c	26 Nov 2003 03:35:16 -0000	1.37
+++ dlls/oleaut32/oleaut.c	14 Dec 2003 10:40:54 -0000
@@ -229,7 +229,7 @@

     /*
      * Allocate a new buffer to hold the string.
-     * dont't forget to keep an empty spot at the beginning of the
+     * don't forget to keep an empty spot at the beginning of the
      * buffer for the character count and an extra character at the
      * end for the NULL.
      */
@@ -344,7 +344,7 @@

     /*
      * Allocate a new buffer to hold the string.
-     * dont't forget to keep an empty spot at the beginning of the
+     * don't forget to keep an empty spot at the beginning of the
      * buffer for the character count and an extra character at the
      * end for the NULL.
      */
Index: dlls/oleaut32/variant.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/variant.c,v
retrieving revision 1.82
diff -u -r1.82 variant.c
--- dlls/oleaut32/variant.c	15 Dec 2003 21:10:53 -0000	1.82
+++ dlls/oleaut32/variant.c	5 Jan 2004 12:55:15 -0000
@@ -1829,7 +1829,7 @@
 HRESULT WINAPI VarNumFromParseNum(NUMPARSE *pNumprs, BYTE *rgbDig,
                                   ULONG dwVtBits, VARIANT *pVarDst)
 {
-  /* Scale factors and limits for double arithmatic */
+  /* Scale factors and limits for double arithmetic */
   static const double dblMultipliers[11] = {
     1.0, 10.0, 100.0, 1000.0, 10000.0, 100000.0,
     1000000.0, 10000000.0, 100000000.0, 1000000000.0, 10000000000.0
@@ -1937,7 +1937,7 @@
     }

     /* If we have any fractional digits, round the value.
-     * Note we dont have to do this if divisor10 is < 1,
+     * Note we don't have to do this if divisor10 is < 1,
      * because this means the fractional part must be < 0.5
      */
     if (!bOverflow && fractionalDigits && divisor10 > 0)
@@ -2420,7 +2420,7 @@
             return VARCMP_GT;
         }
     }
-    FIXME("VarCmp partial implementation, doesnt support vt 0x%x / 0x%x\n",V_VT(left), V_VT(right));
+    FIXME("VarCmp partial implementation, doesn't support vt 0x%x / 0x%x\n",V_VT(left), V_VT(right));
     return E_FAIL;
 }

Index: dlls/oleaut32/vartype.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/vartype.c,v
retrieving revision 1.2
diff -u -r1.2 vartype.c
--- dlls/oleaut32/vartype.c	15 Dec 2003 19:47:10 -0000	1.2
+++ dlls/oleaut32/vartype.c	5 Jan 2004 12:58:17 -0000
@@ -4282,7 +4282,7 @@
   /* Multiply up the value to be scaled by the correct amount */
   while (SUCCEEDED(hRet) && i--)
   {
-    /* Note we are multiplying by a value with a scale of 0, so we dont recurse */
+    /* Note we are multiplying by a value with a scale of 0, so we don't recurse */
     hRet = VarDecMul(&decTemp, &scaleFactor, pDecOut);
     decTemp = *pDecOut;
   }
@@ -5863,8 +5863,8 @@
 }

 /* Date string parsing */
-#define DP_TIMESEP 0x01 /* Time seperator ( _must_ remain 0x1, used as a bitmask) */
-#define DP_DATESEP 0x02 /* Date seperator */
+#define DP_TIMESEP 0x01 /* Time separator ( _must_ remain 0x1, used as a bitmask) */
+#define DP_DATESEP 0x02 /* Date separator */
 #define DP_MONTH   0x04 /* Month name */
 #define DP_AM      0x08 /* AM */
 #define DP_PM      0x10 /* PM */
@@ -5972,7 +5972,7 @@
     }
     else if (dwCount == 1)
     {
-      /* Second: Try all the orders compatable with iDate */
+      /* Second: Try all the orders compatible with iDate */
       switch (iDate)
       {
       case 0:  dwTry = dwAllOrders & ~(ORDER_DMY|ORDER_YDM); break;
@@ -6098,9 +6098,9 @@
  *  Any date format that can be created using the date formats from lcid
  *  (Either from kernel Nls functions, variant conversion or formatting) is a
  *  valid input to this function. In addition, a few more esoteric formats are
- *  also supported for compatability with the native version. The date is
+ *  also supported for compatibility with the native version. The date is
  *  interpreted according to the date settings in the control panel, unless
- *  the date is invalid in that format, in which the most compatable format
+ *  the date is invalid in that format, in which the most compatible format
  *  that produces a valid date will be used.
  */
 HRESULT WINAPI VarDateFromStr(OLECHAR* strIn, LCID lcid, ULONG dwFlags, DATE* pdateOut)
@@ -6276,7 +6276,7 @@
     /* Figure out which numbers correspond to which fields.
      *
      * This switch statement works based on the fact that native interprets any
-     * fields that are not joined with a time seperator ('.' or ':') as date
+     * fields that are not joined with a time separator ('.' or ':') as date
      * fields. Thus we construct a value from 0-32 where each set bit indicates
      * a time field. This encapsulates the hundreds of permutations of 2-6 fields.
      * For valid permutations, we set dwOffset to point to the first date field
Index: dlls/oleaut32/tests/vartest.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/tests/vartest.c,v
retrieving revision 1.20
diff -u -r1.20 vartest.c
--- dlls/oleaut32/tests/vartest.c	2 Jan 2004 01:51:38 -0000	1.20
+++ dlls/oleaut32/tests/vartest.c	5 Jan 2004 12:55:46 -0000
@@ -3799,7 +3799,7 @@
   GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, buff, sizeof(buff)/sizeof(char));
   if (buff[0] != '.' || buff[1])
   {
-    trace("Skipping VarFormatNumber tests as decimal seperator is '%s'\n", buff);
+    trace("Skipping VarFormatNumber tests as decimal separator is '%s'\n", buff);
     return;
   }

@@ -3962,7 +3962,7 @@
   GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, buff, sizeof(buff)/sizeof(char));
   if (buff[0] != '.' || buff[1])
   {
-    trace("Skipping VarFormat tests as decimal seperator is '%s'\n", buff);
+    trace("Skipping VarFormat tests as decimal separator is '%s'\n", buff);
     return;
   }
   GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_IDIGITS, buff, sizeof(buff)/sizeof(char));
@@ -4122,7 +4122,7 @@
     GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, buff, sizeof(buff)/sizeof(char));
     if (buff[0] != '.' || buff[1])
     {
-        trace("Skipping VarAbs(BSTR) as decimal seperator is '%s'\n", buff);
+        trace("Skipping VarAbs(BSTR) as decimal separator is '%s'\n", buff);
         return;
     }
     V_VT(&v) = VT_BSTR;
Index: dlls/oleaut32/tests/vartype.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/tests/vartype.c,v
retrieving revision 1.3
diff -u -r1.3 vartype.c
--- dlls/oleaut32/tests/vartype.c	2 Jan 2004 01:51:38 -0000	1.3
+++ dlls/oleaut32/tests/vartype.c	5 Jan 2004 12:56:36 -0000
@@ -3206,7 +3206,7 @@
   /* 1 element - can only be a time, and only if it has am/pm */
   DFS("1 am"); EXPECT_DBL(0.04166666666666666);
   /* 2 elements */
-  /* A decimal point is treated as a time seperator.
+  /* A decimal point is treated as a time separator.
    * The following are converted as hours/minutes.
    */
   DFS("0.1");  EXPECT_DBL(0.0006944444444444445);
@@ -3255,7 +3255,7 @@
   DFS("Jan/35"); EXPECT_DBL(12785.0);
   DFS("35/Jan"); EXPECT_DBL(12785.0);
   /* 3 elements */
-  /* 3 numbers and time seperator => h:m:s */
+  /* 3 numbers and time separator => h:m:s */
   DFS("0.1.0");  EXPECT_DBL(0.0006944444444444445);
   DFS("1.5.2");  EXPECT_DBL(0.04516203703703704);
   /* 3 numbers => picks date giving preference to lcid format */
@@ -4402,7 +4402,7 @@
   if (HAVE_OLEAUT32_LOCALES)
   {
     /* Numeric strings are read as floating point numbers. The line below fails
-     * because '.' is not a valid decimal seperator for Polish numbers */
+     * because '.' is not a valid decimal separator for Polish numbers */
     CONVERT_STR(VarBoolFromStr,"0.1",0); EXPECT_MISMATCH;
   }

@@ -4481,8 +4481,8 @@
   if (bstr)
   {
     todo_wine {
-    /* MSDN states that rounding of R4/R8 is dependant on the underlying
-     * bit pattern of the number and so is architecture dependant. In this
+    /* MSDN states that rounding of R4/R8 is dependent on the underlying
+     * bit pattern of the number and so is architecture dependent. In this
      * case Wine returns .2 (which is more correct) and Native returns .3
      */
     ok(memcmp(bstr, szNative, sizeof(szNative)) == 0, "string different\n");
Index: dlls/shell32/pidl.h
===================================================================
RCS file: /home/cvs/wine/dlls/shell32/pidl.h,v
retrieving revision 1.31
diff -u -r1.31 pidl.h
--- dlls/shell32/pidl.h	5 Sep 2003 23:08:31 -0000	1.31
+++ dlls/shell32/pidl.h	5 Dec 2003 02:36:55 -0000
@@ -57,11 +57,11 @@
 *	network		0x1F		mycomp
 *	bitbucket	0x1F		mycomp
 *	drive		0x23/25		drive		(usual)
-*	drive		0x25/25		drive		(lnk/persistant)
+*	drive		0x25/25		drive		(lnk/persistent)
 *	drive		0x29/25		drive
 *	shell extension	0x2E		mycomp
-*	drive		0x2F		drive		(lnk/persistant)
-*	folder/file	0x30		folder/file (1)	(lnk/persistant)
+*	drive		0x2F		drive		(lnk/persistent)
+*	folder/file	0x30		folder/file (1)	(lnk/persistent)
 *	folder		0x31		folder		(usual)
 *	valueA		0x32		file		(ANSI file name)
 *	valueW		0x34		file		(Unicode file name)
@@ -73,7 +73,7 @@
 *	history/favorites 0xb1		file
 *	share		0xc3		network (6)
 *
-* guess: the persistant elements are non tracking
+* guess: the persistent elements are non tracking
 *
 * (1) dummy byte is used, attributes are empty
 * (2) IID_MyComputer = 20D04FE0L-3AEA-1069-A2D8-08002B30309D
Index: dlls/shell32/shlexec.c
===================================================================
RCS file: /home/cvs/wine/dlls/shell32/shlexec.c,v
retrieving revision 1.25
diff -u -r1.25 shlexec.c
--- dlls/shell32/shlexec.c	30 Dec 2003 19:20:11 -0000	1.25
+++ dlls/shell32/shlexec.c	4 Jan 2004 21:16:59 -0000
@@ -273,7 +273,7 @@
                                  LPSTR lpResult, LPSTR key, void **env)
 {
     char *extension = NULL; /* pointer to file extension */
-    char tmpext[5];         /* local copy to mung as we please */
+    char tmpext[5];         /* local copy to munge as we please */
     char filetype[256];     /* registry name for this filetype */
     LONG filetypelen = 256; /* length of above */
     char command[256];      /* command from registry */
Index: dlls/shell32/shlmenu.c
===================================================================
RCS file: /home/cvs/wine/dlls/shell32/shlmenu.c,v
retrieving revision 1.34
diff -u -r1.34 shlmenu.c
--- dlls/shell32/shlmenu.c	5 Sep 2003 23:08:31 -0000	1.34
+++ dlls/shell32/shlmenu.c	14 Dec 2003 10:42:13 -0000
@@ -427,7 +427,7 @@
 /*************************************************************************
  * FileMenu_ReplaceUsingPidl			[SHELL32.113]
  *
- * FIXME: the static items are deleted but wont be refreshed
+ * FIXME: the static items are deleted but won't be refreshed
  */
 int WINAPI FileMenu_ReplaceUsingPidl(
 	HMENU	hmenu,
Index: dlls/shlwapi/path.c
===================================================================
RCS file: /home/cvs/wine/dlls/shlwapi/path.c,v
retrieving revision 1.38
diff -u -r1.38 path.c
--- dlls/shlwapi/path.c	22 Sep 2003 19:46:32 -0000	1.38
+++ dlls/shlwapi/path.c	14 Dec 2003 10:39:41 -0000
@@ -2974,7 +2974,7 @@
   if (!lpszPath || !*lpszPath)
     return FALSE;

-  /* If the directory is already a system directory, dont do anything */
+  /* If the directory is already a system directory, don't do anything */
   GetSystemDirectoryW(buff, MAX_PATH);
   if (!strcmpW(buff, lpszPath))
     return TRUE;
Index: dlls/user/resource.c
===================================================================
RCS file: /home/cvs/wine/dlls/user/resource.c,v
retrieving revision 1.19
diff -u -r1.19 resource.c
--- dlls/user/resource.c	26 Nov 2003 22:28:16 -0000	1.19
+++ dlls/user/resource.c	14 Dec 2003 10:40:03 -0000
@@ -348,7 +348,7 @@
 	    buffer[0] = '\0';
 	    return 0;
 	}
-	WARN("Dont know why caller give buflen=%d *p=%d trying to obtain string '%s'\n", buflen, *p, p + 1);
+	WARN("Don't know why caller gave buflen=%d *p=%d trying to obtain string '%s'\n", buflen, *p, p + 1);
     }
     FreeResource16( hmem );

@@ -399,7 +399,7 @@
 	    return 0;
 	}
 #if 0
-	WARN("Dont know why caller give buflen=%d *p=%d trying to obtain string '%s'\n", buflen, *p, p + 1);
+	WARN("Don't know why caller gave buflen=%d *p=%d trying to obtain string '%s'\n", buflen, *p, p + 1);
 #endif
     }

Index: dlls/uxtheme/system.c
===================================================================
RCS file: /home/cvs/wine/dlls/uxtheme/system.c,v
retrieving revision 1.2
diff -u -r1.2 system.c
--- dlls/uxtheme/system.c	8 Dec 2003 22:45:26 -0000	1.2
+++ dlls/uxtheme/system.c	5 Jan 2004 13:02:51 -0000
@@ -161,7 +161,7 @@
  *      EnableTheming                                       (UXTHEME.@)
  *
  * NOTES
- * This is a global and persistant change
+ * This is a global and persistent change
  */
 HRESULT WINAPI EnableTheming(BOOL fEnable)
 {
@@ -228,7 +228,7 @@
 /***********************************************************************
  *      SetWindowTheme                                      (UXTHEME.@)
  *
- * Persistant through the life of the window, even after themes change
+ * Persistent through the life of the window, even after themes change
  */
 HRESULT WINAPI SetWindowTheme(HWND hwnd, LPCWSTR pszSubAppName,
                               LPCWSTR pszSubIdList)
@@ -396,9 +396,9 @@
  *
  * PARAMS
  *     pszThemeFileName    Path to a msstyles theme file
- *     pszColorName        Buffer to recieve the default color name
+ *     pszColorName        Buffer to receive the default color name
  *     dwColorNameLen      Length, in characters, of color name buffer
- *     pszSizeName         Buffer to recieve the default size name
+ *     pszSizeName         Buffer to receive the default size name
  *     dwSizeNameLen       Length, in characters, of size name buffer
  */
 HRESULT WINAPI GetThemeDefaults(LPCWSTR pszThemeFileName, LPWSTR pszColorName,
Index: dlls/uxtheme/uxthemedll.h
===================================================================
RCS file: /home/cvs/wine/dlls/uxtheme/uxthemedll.h,v
retrieving revision 1.1
diff -u -r1.1 uxthemedll.h
--- dlls/uxtheme/uxthemedll.h	4 Dec 2003 20:55:30 -0000	1.1
+++ dlls/uxtheme/uxthemedll.h	14 Dec 2003 10:37:51 -0000
@@ -60,7 +60,7 @@
  *     lpData              Value passed through lpData from ParseThemeIniFile
  *
  * NOTES
- * I dont know what the valid entry types are
+ * I don't know what the valid entry types are
  */
 typedef BOOL (CALLBACK*ParseThemeIniFileProc)(DWORD dwType, LPWSTR pszParam1,
                                               LPWSTR pszParam2, LPWSTR pszParam3,
Index: dlls/winedos/int10.c
===================================================================
RCS file: /home/cvs/wine/dlls/winedos/int10.c,v
retrieving revision 1.35
diff -u -r1.35 int10.c
--- dlls/winedos/int10.c	2 Jan 2004 21:08:41 -0000	1.35
+++ dlls/winedos/int10.c	6 Jan 2004 12:29:14 -0000
@@ -987,7 +987,7 @@
         break;

     case 0xff: /* Turn VESA ON/OFF */
-        /* i dont know what to do */
+        /* I don't know what to do */
         break;

     default:
@@ -1024,8 +1024,8 @@
  *
  *  Jess Haas 2/99
  *	Added support for Vesa. It is not complete but is a start.
- *	NOTE: Im not sure if i did all this right or if eny of it works.
- *	Currently i dont have a program that uses Vesa that actually gets far
+ *	NOTE: Im not sure if I did all this right or if any of it works.
+ *	Currently I don't have a program that uses Vesa that actually gets far
  *	enough without crashing to do vesa stuff.
  *
  *      Added additional vga graphic support - 3/99
Index: dlls/winmm/winemm.h
===================================================================
RCS file: /home/cvs/wine/dlls/winmm/winemm.h,v
retrieving revision 1.52
diff -u -r1.52 winemm.h
--- dlls/winmm/winemm.h	31 Dec 2003 23:49:45 -0000	1.52
+++ dlls/winmm/winemm.h	4 Jan 2004 21:17:10 -0000
@@ -70,7 +70,7 @@
     int				nIDMin;		/* lower bound of global indexes for this type */
     int				nIDMax;		/* hhigher bound of global indexes for this type */
     union {
-	WINEMM_msgFunc32	fnMessage32;	/* pointer to fonction */
+	WINEMM_msgFunc32	fnMessage32;	/* pointer to function */
 	WINEMM_msgFunc16	fnMessage16;
     } u;
 } WINE_MM_DRIVER_PART;
Index: dlls/winmm/wineaudioio/audio.c
===================================================================
RCS file: /home/cvs/wine/dlls/winmm/wineaudioio/audio.c,v
retrieving revision 1.8
diff -u -r1.8 audio.c
--- dlls/winmm/wineaudioio/audio.c	22 Sep 2003 21:13:33 -0000	1.8
+++ dlls/winmm/wineaudioio/audio.c	6 Jan 2004 12:38:02 -0000
@@ -22,9 +22,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *
- * Note large hacks done to effectively  disable DSound altogether
- *  Also Input is not yet working (Lots more work to be done there)
-  * But this does make a reasonable output driver for solaris untill the arts driver comes up to speed
+ * Note large hacks done to effectively disable DSound altogether
+ * Also Input is not yet working (Lots more work to be done there)
+ * But this does make a reasonable output driver for solaris until the arts
+ * driver comes up to speed
  */

 /*
@@ -248,9 +249,9 @@
     WOutDev[0].caps.dwSupport = WAVECAPS_VOLUME;

     /*
-     * Libaudioio works differently, you tell it what spec audio you want to write and it
-     * Guarantees to match it by converting to the final format on the fly
-     *So we dont need to read  back and compare
+     * Libaudioio works differently, you tell it what spec audio you want to write
+     * and it guarantees to match it by converting to the final format on the fly.
+     * So we don't need to read  back and compare.
      */

     bytespersmpl = spec[PLAYBACK].precision/8;
@@ -273,7 +274,7 @@
 	    if (WOutDev[0].caps.wChannels > 1)
 		WOutDev[0].caps.dwFormats |= WAVE_FORMAT_4S16;

-/* Don't understand this yet, but I dont think this functionality is portable, leave here for future evaluation
+/* Don't understand this yet, but I don't think this functionality is portable, leave it here for future evaluation
  *   if (IOCTL(audio, SNDCTL_DSP_GETCAPS, caps) == 0) {
  *	TRACE("OSS dsp out caps=%08X\n", caps);
  *	if ((caps & DSP_CAP_REALTIME) && !(caps & DSP_CAP_BATCH)) {
Index: dlls/x11drv/xfont.c
===================================================================
RCS file: /home/cvs/wine/dlls/x11drv/xfont.c,v
retrieving revision 1.1
diff -u -r1.1 xfont.c
--- dlls/x11drv/xfont.c	5 Dec 2003 00:20:28 -0000	1.1
+++ dlls/x11drv/xfont.c	14 Dec 2003 10:39:55 -0000
@@ -501,7 +501,7 @@
     int i;

     if (!buf_size)
-	return; /* Dont be silly */
+	return; /* Don't be silly */

     lfd_fld[0]  = lfd->foundry;
     lfd_fld[1]	= lfd->family;
@@ -2520,7 +2520,7 @@
 	   else
 	   {
 	       ERR("PixHeight == InternalLeading\n");
-	       penalty += 0x1000; /* dont want this */
+	       penalty += 0x1000; /* don't want this */
 	   }
        }
    }
Index: documentation/getting.sgml
===================================================================
RCS file: /home/cvs/wine/documentation/getting.sgml,v
retrieving revision 1.18
diff -u -r1.18 getting.sgml
--- documentation/getting.sgml	5 Jan 2004 21:16:53 -0000	1.18
+++ documentation/getting.sgml	5 Jan 2004 23:56:17 -0000
@@ -182,7 +182,7 @@
           Often a package will only work on the distribution which it
 	  has been compiled for.  We'll cover
           <link linkend="getting-dist-debian">Debian Linux</link>,
-          <link linkend="getting-dist-linux">Red Hat, Mandrake, Suse and Slackware Linux</link>,
+          <link linkend="getting-dist-linux">Red Hat, Mandrake, SuSE and Slackware Linux</link>,
           <link linkend="getting-freebsd">FreeBSD</link>, and
           <link linkend="getting-other">other</link> distributions.
         </para>
@@ -268,10 +268,10 @@
       </sect2>

       <sect2 id="getting-dist-linux">
-        <title>Linux Red Hat, Mandrake, Suse, and Slackware</title>
+        <title>Linux Red Hat, Mandrake, SuSE, and Slackware</title>

         <para>
-          Red Hat, Mandrake, Suse and Slackware users can download
+          Red Hat, Mandrake, SuSE and Slackware users can download
 	  a wine binary from the
           <ulink url="http://sourceforge.net/project/showfiles.php?group_id=6241">
           sourceforge.net Wine download page</ulink>
@@ -320,7 +320,7 @@
 	   linkend="config-wine-main">Configuration section</link>.
 	 </para>
 	 <para>
-	 You can also download a Freebsd package of wine from the
+	 You can also download a FreeBSD package of wine from the
 	 <ulink url="http://sourceforge.net/project/showfiles.php?group_id=6241">
           sourceforge.net Wine download page</ulink>
 	  </para>
Index: files/file.c
===================================================================
RCS file: /home/cvs/wine/files/file.c,v
retrieving revision 1.197
diff -u -r1.197 file.c
--- files/file.c	15 Dec 2003 20:15:20 -0000	1.197
+++ files/file.c	15 Dec 2003 20:51:33 -0000
@@ -1782,7 +1782,7 @@

     /* FIXME: <Gerhard W. Gruber>sparhawk at gmx.at
        In case of W9x and lesser this function should return 120 (ERROR_CALL_NOT_IMPLEMENTED)
-       to be really compatible. Most programs wont have any problems though. In case
+       to be really compatible. Most programs won't have any problems though. In case
        you encounter one, this is what you should return here. I don't know what's up
        with NT 3.5. Is this function available there or not?
        Does anybody really care about 3.5? :)
Index: include/shlwapi.h
===================================================================
RCS file: /home/cvs/wine/include/shlwapi.h,v
retrieving revision 1.39
diff -u -r1.39 shlwapi.h
--- include/shlwapi.h	23 Sep 2003 22:49:56 -0000	1.39
+++ include/shlwapi.h	14 Dec 2003 10:37:38 -0000
@@ -190,7 +190,7 @@
     ASSOCF_VERIFY               = 0x040, /* Verify data */
     ASSOCF_REMAPRUNDLL          = 0x080, /* Get rundll args */
     ASSOCF_NOFIXUPS             = 0x100, /* Don't fixup errors */
-    ASSOCF_IGNOREBASECLASS      = 0x200, /* Dont read baseclass */
+    ASSOCF_IGNOREBASECLASS      = 0x200, /* Don't read baseclass */
 };

 typedef DWORD ASSOCF;
Index: programs/wcmd/wcmdmain.c
===================================================================
RCS file: /home/cvs/wine/programs/wcmd/wcmdmain.c,v
retrieving revision 1.38
diff -u -r1.38 wcmdmain.c
--- programs/wcmd/wcmdmain.c	9 Oct 2003 04:39:01 -0000	1.38
+++ programs/wcmd/wcmdmain.c	14 Dec 2003 10:37:27 -0000
@@ -286,7 +286,7 @@
       return;
     }

-    /* Dont issue newline WCMD_output (newline);           @JED*/
+    /* Don't issue newline WCMD_output (newline);           @JED*/

     sa.nLength = sizeof(sa);
     sa.lpSecurityDescriptor = NULL;
Index: tools/c2man.pl
===================================================================
RCS file: /home/cvs/wine/tools/c2man.pl,v
retrieving revision 1.12
diff -u -r1.12 c2man.pl
--- tools/c2man.pl	1 Oct 2003 03:05:43 -0000	1.12
+++ tools/c2man.pl	14 Dec 2003 10:42:49 -0000
@@ -620,7 +620,7 @@
 {
   my $comment = shift(@_);

-  # Don't process this comment if the function isnt exported
+  # Don't process this comment if the function isn't exported
   my $spec_details = $spec_files{$comment->{DLL_NAME}}[0];

   if (!defined($spec_details))
@@ -793,7 +793,7 @@
       {
         if ( !/^[A-Z]+$/ )
         {
-          # Dont reject comments that refer to another doc (e.g. A/W)
+          # Don't reject comments that refer to another doc (e.g. A/W)
           if ( /^See ([A-Za-z0-9_]+)\.$/ )
           {
             if ($comment->{COMMENT_NAME} =~ /W$/ )
Index: tools/wineinstall
===================================================================
RCS file: /home/cvs/wine/tools/wineinstall,v
retrieving revision 1.62
diff -u -r1.62 wineinstall
--- tools/wineinstall	26 Nov 2003 03:55:01 -0000	1.62
+++ tools/wineinstall	14 Dec 2003 10:37:07 -0000
@@ -285,7 +285,7 @@
           sucommand="$sucommand;echo $libdir>>/etc/ld.so.conf"
         }
         fi
-        # run ldconfig always just in case some updated files dont get linked
+        # run ldconfig always just in case some updated files don't get linked
         sucommand="$sucommand;$ac_cv_path_LDCONFIG"
       fi
     }
Index: tools/winedump/README
===================================================================
RCS file: /home/cvs/wine/tools/winedump/README,v
retrieving revision 1.6
diff -u -r1.6 README
--- tools/winedump/README	22 Jul 2003 00:56:46 -0000	1.6
+++ tools/winedump/README	5 Jan 2004 12:54:23 -0000
@@ -507,7 +507,7 @@
 By adding '#include "fixup.h"' to foobar_dll.h your compile errors will be
 greatly reduced.

-If winedump encounters a type it doesnt know that is passed by value (as in
+If winedump encounters a type it doesn't know that is passed by value (as in
 the _cabs example above), it also prints a FIXME message like:

 /* FIXME: By value type: Assumed 'int' */ typedef int ldiv_t;
@@ -634,7 +634,7 @@
 and generating them myself is very slow.

 Finally, although it is easy to generate a DLL, I _very strongly_ suggest that
-you dont submit a generated DLL for inclusion into Wine unless you have
+you don't submit a generated DLL for inclusion into Wine unless you have
 actually implemented a fairly reasonable portion of it. Even then, you should
 only send the portions of the DLL you have implemented. Thousands of lines of
 stub code don't help the project at all.



Index: dlls/d3d8/device.c
===================================================================
RCS file: /home/cvs/wine/dlls/d3d8/device.c,v
retrieving revision 1.93
diff -u -r1.93 device.c
--- dlls/d3d8/device.c	17 Nov 2003 20:04:30 -0000	1.93
+++ dlls/d3d8/device.c	5 Jan 2004 13:01:03 -0000
@@ -124,7 +124,7 @@
 #endif
                    checkGLcall("glActiveTextureARB");
                 } else if (Stage > 0) {
-                    FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+                    FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
                 }
                 changeTexture = FALSE;
            }
@@ -487,7 +487,7 @@


     glXSwapBuffers(This->display, This->drawable);
     /* Dont call checkGLcall, as glGetError is not applicable here */
     TRACE("glXSwapBuffers called, Starting new frame\n");

     /* FPS support */
@@ -986,7 +986,7 @@
           pSourceSurface, pSourceRectsArray, cRects, pDestinationSurface, pDestPointsArray);

     /* Note: Not sure about the d3dfmt_unknown bit, but seems to avoid a problem inside
-         a sample and doesnt seem to break anything as far as I can tell               */
+         a sample and doesn't seem to break anything as far as I can tell               */
     if (src->myDesc.Format != dst->myDesc.Format && (dst->myDesc.Format != D3DFMT_UNKNOWN)) {
         TRACE("Formats do not match (%x,%s) / (%x,%s)\n",
                src->myDesc.Format, debug_d3dformat(src->myDesc.Format),
@@ -2119,7 +2119,7 @@

     /* Validate Index */
     if (Index >= GL_LIMITS(clipplanes)) {
-        TRACE("Application has requested clipplane this device doesnt support\n");
+        TRACE("Application has requested clipplane this device doesn't support\n");
         return D3DERR_INVALIDCALL;
     }

@@ -2165,7 +2165,7 @@

     /* Validate Index */
     if (Index >= GL_LIMITS(clipplanes)) {
-        TRACE("Application has requested clipplane this device doesnt support\n");
+        TRACE("Application has requested clipplane this device doesn't support\n");
         return D3DERR_INVALIDCALL;
     }

@@ -2271,7 +2271,7 @@
             checkGLcall("glShadeModel");
             break;
         case D3DSHADE_PHONG:
-            FIXME("D3DSHADE_PHONG isnt supported?\n");
+            FIXME("D3DSHADE_PHONG isn't supported?\n");

 	    LEAVE_GL();
             return D3DERR_INVALIDCALL;
@@ -2508,7 +2508,7 @@
 #endif
                     checkGLcall("Activate texture.. to update const color");
                 } else if (i>0) {
-                    FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+                    FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
                 }

                 glTexEnvfv(GL_TEXTURE_ENV, GL_TEXTURE_ENV_COLOR, &col[0]);
@@ -2526,8 +2526,8 @@
                single color means it is merged in. However in both cases they are being used to
                some extent.
                To disable specular color, set it explicitly to black and turn off GL_COLOR_SUM_EXT
-               NOTE: If not supported dont give FIXME as very minimal impact and very few people are
-                  yet running 1.4!
+               NOTE: If not supported don't give FIXMEs the impact is really minimal and very few people are
+                  running 1.4 yet!
              */
               if (Value) {
                 glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, (float*) &This->UpdateStateBlock->material.Specular);
@@ -3072,7 +3072,7 @@
 #endif
         checkGLcall("glActiveTextureARB");
     } else if (Stage>0) {
-        FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+        FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
     }

     /* Decrement the count of the previous texture */
@@ -3206,7 +3206,7 @@
         vcheckGLcall("glActiveTextureARB");
 #endif
     } else if (Stage > 0) {
-        FIXME("Program using multiple concurrent textures which this opengl implementation doesnt support\n");
+        FIXME("Program using multiple concurrent textures which this opengl implementation doesn't support\n");
     }

     switch (Type) {
@@ -3243,7 +3243,7 @@
                     realVal = GL_LINEAR_MIPMAP_LINEAR;
                 }
             } else if (ValueMIN == D3DTEXF_NONE) {
                 /* Doesnt really make sense - Windows just seems to disable
                    mipmapping when this occurs                              */
                 FIXME("Odd - minfilter of none, just disabling mipmaps\n");
                 realVal = GL_LINEAR;
@@ -3292,7 +3292,7 @@
                 checkGLcall("Disable GL_TEXTURE_2D");
                 glDisable(GL_TEXTURE_3D);
                 checkGLcall("Disable GL_TEXTURE_3D");
-                break; /* Dont bother setting the texture operations */
+                break; /* Don't bother setting the texture operations */
             } else {
                 /* Enable only the appropriate texture dimension */
                 if (Type == D3DTSS_COLOROP) {
@@ -487,7 +487,7 @@

     glXSwapBuffers(This->display, This->drawable);
-    /* Dont call checkGLcall, as glGetError is not applicable here */
+    /* Don't call checkGLcall, as glGetError is not applicable here */
     TRACE("glXSwapBuffers called, Starting new frame\n");

@@ -3243,7 +3243,7 @@
                 }
             } else if (ValueMIN == D3DTEXF_NONE) {
-                /* Doesnt really make sense - Windows just seems to disable
+                /* Doesn't really make sense - Windows just seems to disable
                    mipmapping when this occurs                              */
                 FIXME("Odd - minfilter of none, just disabling mipmaps\n");
Index: dlls/oleaut32/varformat.c
===================================================================
RCS file: /home/cvs/wine/dlls/oleaut32/varformat.c,v
retrieving revision 1.1
diff -u -r1.1 varformat.c
--- dlls/oleaut32/varformat.c	25 Nov 2003 01:49:31 -0000	1.1
+++ dlls/oleaut32/varformat.c	2 Dec 2003 21:52:13 -0000
@@ -88,11 +88,11 @@
  *| True/False     Localised text of "True" or "False"
  *| Yes/No         Localised text of "Yes" or "No"
  *| On/Off         Localised text of "On" or "Off"
  *| General Number No thousands seperator. No decimal points for integers
  *| Currency       General currency format using localised characters
  *| Fixed          At least one whole and two fractional digits
- *| Standard       As for 'Fixed', but including decimal seperators
- *| Percent        Multiply by 100 and dispaly a traling '%' character
+ *| Standard       Same as 'Fixed', but including decimal separators
+ *| Percent        Multiply by 100 and display a trailing '%' character
  *| Scientific     Display with exponent
  *
  *  User-defined formats consist of a combination of tokens and literal
@@ -103,7 +103,7 @@
  *  (e.g. "\L\i\t\e\r\a\l") or enclosing it in double quotes.
  *
  *  A user-defined format can have up to 4 sections, depending on the type of
- *  format, The following table lists sections and their meaning:
+ *  format. The following table lists sections and their meaning:
  *| Format Type  Sections Meaning
  *| -----------  -------- -------
  *| Number       1        Use the same format for all numbers
@@ -208,7 +208,7 @@

 #define FMT_FLAG_PERCENT   0x1  /* Has '%' (Percentage) */
 #define FMT_FLAG_EXPONENT  0x2  /* Has 'e' (Exponent/Scientific notation) */
-#define FMT_FLAG_THOUSANDS 0x4  /* Has ',' (Standard use of the thousands seperator) */
+#define FMT_FLAG_THOUSANDS 0x4  /* Has ',' (Standard use of the thousands separator) */
 #define FMT_FLAG_BOOL      0x20 /* Boolean format */

 typedef struct tagFMT_NUMBER_HEADER
@@ -238,8 +238,8 @@
 #define FMT_GEN_COPY        0x00 /* \n, "lit" => 0,pos,len: Copy len chars from input+pos */
 #define FMT_GEN_INLINE      0x01 /*      => 1,len,[chars]: Copy len chars from token stream */
 #define FMT_GEN_END         0x02 /* \0,; => 2: End of the tokenised format */
-#define FMT_DATE_TIME_SEP   0x03 /* Time seperator char */
-#define FMT_DATE_DATE_SEP   0x04 /* Date seperator char */
+#define FMT_DATE_TIME_SEP   0x03 /* Time separator char */
+#define FMT_DATE_DATE_SEP   0x04 /* Date separator char */
 #define FMT_DATE_GENERAL    0x05 /* General format date */
 #define FMT_DATE_QUARTER    0x06 /* Quarter of the year from 1-4 */
 #define FMT_DATE_TIME_SYS   0x07 /* System long time format */
@@ -278,7 +278,7 @@
 #define FMT_DATE_A_LOWER    0x33 /* Lower-case A or P */
 #define FMT_NUM_COPY_ZERO   0x34 /* Copy 1 digit or 0 if no digit */
 #define FMT_NUM_COPY_SKIP   0x35 /* Copy 1 digit or skip if no digit */
-#define FMT_NUM_DECIMAL     0x36 /* Decimal seperator */
+#define FMT_NUM_DECIMAL     0x36 /* Decimal separator */
 #define FMT_NUM_EXP_POS_U   0x37 /* Scientific notation, uppercase, + sign */
 #define FMT_NUM_EXP_NEG_U   0x38 /* Scientific notation, lowercase, - sign */
 #define FMT_NUM_EXP_POS_L   0x39 /* Scientific notation, uppercase, + sign */
@@ -481,7 +481,7 @@

 /* State during tokenising */
 #define FMT_STATE_OPEN_COPY     0x1 /* Last token written was a copy */
-#define FMT_STATE_WROTE_DECIMAL 0x2 /* Already wrote a decimal seperator */
+#define FMT_STATE_WROTE_DECIMAL 0x2 /* Already wrote a decimal separator */
 #define FMT_STATE_SEEN_HOURS    0x4 /* See the hh specifier */
 #define FMT_STATE_WROTE_MINUTES 0x8 /* Wrote minutes */

@@ -624,7 +624,7 @@
     else if (*pFormat == '"')
     {
       /* Escaped string
-       * Note: Native encodes "" as a copy of length zero. Thats just dumb, so
+       * Note: Native encodes "" as a copy of length zero. That's just dumb, so
        * here we avoid encoding anything in this case.
        */
       if (!pFormat[1])
@@ -701,7 +701,7 @@
     else if (*pFormat == '.' && COULD_BE(FMT_TYPE_NUMBER) &&
               !(fmt_state & FMT_STATE_WROTE_DECIMAL))
     {
       /* Number formats: Decimal seperator when 1st seen, literal thereafter
        * Other formats: Literal
        * Types the format if found
        */
@@ -717,7 +717,7 @@
     /* FIXME: %% => Divide by 1000 */
     else if (*pFormat == ',' && header->type == FMT_TYPE_NUMBER)
     {
       /* Number formats: Use the thousands seperator
        * Other formats: Literal
        */
       num_header->flags |= FMT_FLAG_THOUSANDS;
@@ -731,7 +731,7 @@
      */
     else if (*pFormat == '/' && COULD_BE(FMT_TYPE_DATE))
     {
       /* Date formats: Date seperator
        * Other formats: Literal
        * Types the format if found
        */
@@ -744,7 +744,7 @@
     }
     else if (*pFormat == ':' && COULD_BE(FMT_TYPE_DATE))
     {
       /* Date formats: Time seperator
        * Other formats: Literal
        * Types the format if found
        */
@@ -1159,7 +1159,7 @@
 }

 /* Number formatting state flags */
-#define NUM_WROTE_DEC  0x01 /* Written the decimal seperator */
+#define NUM_WROTE_DEC  0x01 /* Written the decimal separator */

 /* Format a variant using a number format */
 static HRESULT VARIANT_FormatNumber(LPVARIANT pVarIn, LPOLESTR lpszFormat,
@@ -1347,7 +1347,7 @@
       break;

     case FMT_NUM_DECIMAL:
-      TRACE("write decimal seperator\n");
+      TRACE("write decimal separator\n");
       localeValue = LOCALE_SDECIMAL;
       defaultChar = '.';
       dwState |= NUM_WROTE_DEC;
@@ -1552,13 +1552,13 @@
       break;

     case FMT_DATE_TIME_SEP:
-      TRACE("time seperator\n");
+      TRACE("time separator\n");
       localeValue = LOCALE_STIME;
       defaultChar = ':';
       break;

     case FMT_DATE_DATE_SEP:
-      TRACE("date seperator\n");
+      TRACE("date separator\n");
       localeValue = LOCALE_SDATE;
       defaultChar = '/';
       break;
@@ -88,11 +88,11 @@
  *| Yes/No         Localised text of "Yes" or "No"
  *| On/Off         Localised text of "On" or "Off"
- *| General Number No thousands seperator. No decimal points for integers
+ *| General Number No thousands separator. No decimal points for integers
  *| Currency       General currency format using localised characters
  *| Fixed          At least one whole and two fractional digits
@@ -701,7 +701,7 @@
               !(fmt_state & FMT_STATE_WROTE_DECIMAL))
     {
-      /* Number formats: Decimal seperator when 1st seen, literal thereafter
+      /* Number formats: Decimal separator when 1st seen, literal thereafter
        * Other formats: Literal
        * Types the format if found
@@ -717,7 +717,7 @@
     else if (*pFormat == ',' && header->type == FMT_TYPE_NUMBER)
     {
-      /* Number formats: Use the thousands seperator
+      /* Number formats: Use the thousands separator
        * Other formats: Literal
        */
@@ -731,7 +731,7 @@
     else if (*pFormat == '/' && COULD_BE(FMT_TYPE_DATE))
     {
-      /* Date formats: Date seperator
+      /* Date formats: Date separator
        * Other formats: Literal
        * Types the format if found
@@ -744,7 +744,7 @@
     else if (*pFormat == ':' && COULD_BE(FMT_TYPE_DATE))
     {
-      /* Date formats: Time seperator
+      /* Date formats: Time separator
        * Other formats: Literal
        * Types the format if found
Index: dlls/winspool/info.c
===================================================================
RCS file: /home/cvs/wine/dlls/winspool/info.c,v
retrieving revision 1.89
diff -u -r1.89 info.c
--- dlls/winspool/info.c	2 Jan 2004 01:49:31 -0000	1.89
+++ dlls/winspool/info.c	4 Jan 2004 21:17:13 -0000
@@ -2136,8 +2136,8 @@
 	return TRUE;

     if (dwType & PRINTER_ENUM_CONNECTIONS) {
-        FIXME("We dont handle PRINTER_ENUM_CONNECTIONS\n");
-	dwType &= ~PRINTER_ENUM_CONNECTIONS; /* we dont handle that */
+        FIXME("We don't handle PRINTER_ENUM_CONNECTIONS\n");
+	dwType &= ~PRINTER_ENUM_CONNECTIONS; /* we don't handle that */
         if(!dwType) return TRUE;
     }

-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
                  Hiroshima '45 - Czernobyl '86 - Windows '95



More information about the wine-patches mailing list